! ****+*****************************************************************
! Name           : Subroutine DECOUP_ZONE
! Creation date  : 04/09/2006
! actual version : 0.1
! auteur         : Frank Guillaume - CNRM/GMAP/OBS
! ----+-----------------------------------------------------------------
! Description    : permet d'obtenir les latitudes et longitudes
!                  definissant une boite, incluse dans un domaine
!                  specifie par l'appelant.
!
! arguments IN   : ZLATN latitude nord du domaine,
!                  ZLATS latitude sud du domaine,
!                  ZLONO longitude ouest du domaine,
!                  ZLONE longitude est du domaine,
!                  IPASLAT increment en latitude,
!                  IPASLON increment en longitude,
!                  ITERLAT numero d'iteration en latitude,
!                  ITERLON numero d'iteration en longitude.
!                  LMERIDIAN =.TRUE. si on passe par le meridien 180
!
! arguments OUT  : ZLATBN latitude nord de la boite,
!                  ZLATBS latitide sud de la boite,
!                  ZLONBO longitude ouest de la boite,
!                  ZLONBE longitude est de la boite.
!
! ----+-----------------------------------------------------------------
! History :  0.1 - first release
! ====+=================================================================

      SUBROUTINE DECOUP_ZONE(ZLATN , ZLATS , IPASLAT, ITERLAT,
     &                       ZLONO , ZLONE , IPASLON, ITERLON,
     &                       ZLATBN, ZLATBS, ZLONBO , ZLONBE,
     &                       LMERIDIAN)
     
      IMPLICIT LOGICAL(L)

#include "oulan_yomcsts.h"

      REAL,INTENT(IN)    :: ZLATN,ZLATS,ZLONO,ZLONE
      INTEGER,INTENT(IN) :: IPASLAT,ITERLAT,IPASLON,ITERLON
      LOGICAL,INTENT(IN) :: LMERIDIAN
      REAL,INTENT(OUT)   :: ZLATBN,ZLATBS,ZLONBO,ZLONBE
      REAL,PARAMETER     :: ZEPSILON = 0.00001
      REAL               :: ZLONMIN

! determination des bornes de la boite en latitude ---------------------

      IF ((ZLATN-ZLATS) < IPASLAT .OR. IPASLAT == 0) THEN
         ZLATBN = ZLATN
         ZLATBS = ZLATS
      ELSE
         ZLATBN = ZLATN - (ITERLAT - 1) * IPASLAT
         ZLATBS = MAX(ZLATBN - IPASLAT + ZEPSILON,ZLATS)
      ENDIF
       

! determination des bornes de la boite en longitude --------------------

      IF (IPASLON == 0) THEN
         ZLONBE = ZLONE
	 ZLONBO = ZLONO
      ELSE
         ZLONBE = ZLONE - (ITERLON - 1)* IPASLON
         ZLONBO = ZLONBE - IPASLON + ZEPSILON
         IF (LMERIDIAN) THEN
            ZLONMIN = -360.+ZLONO
	    IF (ZLONBE <= -180.) ZLONBE = ZLONBE + 360.
	    IF (ZLONBO <  -180.) ZLONBO = MAX(ZLONBO,ZLONMIN) + 360.
         ELSE
            ZLONBO = MAX(ZLONBO,ZLONO)
         ENDIF
      ENDIF
      
!      WRITE(NULOUT,'(4F10.5)') ZLATBN,ZLATBS,ZLONBO,ZLONBE
      END SUBROUTINE
